| Title: | Java Graphics Device |
|---|---|
| Description: | Graphics device routing all graphics commands to a Java program. The actual functionality of the JavaGD depends on the Java-side implementation. Simple AWT and Swing implementations are included. |
| Authors: | Simon Urbanek [aut, cre, cph] (https://urbanek.nz, ORCID: <https://orcid.org/0000-0003-2297-1732>) |
| Maintainer: | Simon Urbanek <[email protected]> |
| License: | GPL-2 | GPL-3 |
| Version: | 0.5-3 |
| Built: | 2026-05-26 05:50:56 UTC |
| Source: | https://github.com/s-u/javagd |
JavaGD initializes a new Java grapgics device and creates a new window.
JavaGD(name="JavaGD", width=400, height=300, ps=12)JavaGD(name="JavaGD", width=400, height=300, ps=12)
name |
Name of the device |
width |
Initial width of the window (usually in pixels, but the actual interpretation depends on the Java implementation) |
height |
Initial height of the window |
ps |
Initial point size |
Currently the return value is implementation dependent, mostly just the return code as returned by the low-level C function
## Not run: JavaGD() ## End(Not run)## Not run: JavaGD() ## End(Not run)